@@ -1,6 +1,6 @@
 /* -*- mode: C; c-file-style: "gnu"; indent-tabs-mode: nil; -*- */
 /*
- * Copyright (C) 2011, 2012, 2015 Red Hat, Inc.
+ * Copyright (C) 2011, 2012 Red Hat, Inc.
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -25,9 +25,6 @@
 #include "goadaemon.h"
 #include "goabackend/goabackend.h"
 #include "goabackend/goautils.h"
-#ifdef GOA_KERBEROS_ENABLED
-#include "goaidentity/goaidentityservice.h"
-#endif
 
 struct _GoaDaemon
 {
@@ -39,21 +36,11 @@ struct _GoaDaemon
   GFileMonitor *home_conf_file_monitor;
   GFileMonitor *home_conf_dir_monitor;
 
-  GNetworkMonitor *network_monitor;
-
   GDBusObjectManagerServer *object_manager;
 
   GoaManager *manager;
 
-#ifdef GOA_KERBEROS_ENABLED
-  GoaIdentityService *identity_service;
-#endif
-
-  GQueue *ensure_credentials_queue;
-  gboolean ensure_credentials_running;
-
   guint config_timeout_id;
-  guint credentials_timeout_id;
 };
 
 typedef struct
@@ -84,52 +71,39 @@ static gboolean on_account_handle_ensure_credentials (GoaAccount            *acc
                                                       GDBusMethodInvocation *invocation,
                                                       gpointer               user_data);
 
-static void ensure_credentials_queue_check (GoaDaemon *self);
-
-static void goa_daemon_check_credentials (GoaDaemon *self);
-static void goa_daemon_reload_configuration (GoaDaemon *self);
+static void goa_daemon_reload_configuration (GoaDaemon *daemon);
 
 G_DEFINE_TYPE (GoaDaemon, goa_daemon, G_TYPE_OBJECT);
 
 static void
 goa_daemon_finalize (GObject *object)
 {
-  GoaDaemon *self = GOA_DAEMON (object);
+  GoaDaemon *daemon = GOA_DAEMON (object);
 
-  if (self->config_timeout_id != 0)
+  if (daemon->config_timeout_id != 0)
     {
-      g_source_remove (self->config_timeout_id);
+      g_source_remove (daemon->config_timeout_id);
     }
 
-  if (self->credentials_timeout_id != 0)
+  if (daemon->system_conf_dir_monitor != NULL)
     {
-      g_source_remove (self->credentials_timeout_id);
+      g_signal_handlers_disconnect_by_func (daemon->system_conf_dir_monitor, on_file_monitor_changed, daemon);
+      g_object_unref (daemon->system_conf_dir_monitor);
+    }
+  if (daemon->home_conf_dir_monitor != NULL)
+    {
+      g_signal_handlers_disconnect_by_func (daemon->home_conf_dir_monitor, on_file_monitor_changed, daemon);
+      g_object_unref (daemon->home_conf_dir_monitor);
+    }
+  if (daemon->home_conf_file_monitor != NULL)
+    {
+      g_signal_handlers_disconnect_by_func (daemon->home_conf_file_monitor, on_file_monitor_changed, daemon);
+      g_object_unref (daemon->home_conf_file_monitor);
     }
 
-  if (self->system_conf_dir_monitor != NULL)
-    {
-      g_signal_handlers_disconnect_by_func (self->system_conf_dir_monitor, on_file_monitor_changed, self);
-      g_object_unref (self->system_conf_dir_monitor);
-    }
-  if (self->home_conf_dir_monitor != NULL)
-    {
-      g_signal_handlers_disconnect_by_func (self->home_conf_dir_monitor, on_file_monitor_changed, self);
-      g_object_unref (self->home_conf_dir_monitor);
-    }
-  if (self->home_conf_file_monitor != NULL)
-    {
-      g_signal_handlers_disconnect_by_func (self->home_conf_file_monitor, on_file_monitor_changed, self);
-      g_object_unref (self->home_conf_file_monitor);
-    }
-
-  g_object_unref (self->manager);
-  g_object_unref (self->object_manager);
-  g_object_unref (self->connection);
-  g_queue_free_full (self->ensure_credentials_queue, g_object_unref);
-
-#ifdef GOA_KERBEROS_ENABLED
-  g_clear_object (&self->identity_service);
-#endif
+  g_object_unref (daemon->manager);
+  g_object_unref (daemon->object_manager);
+  g_object_unref (daemon->connection);
 
   G_OBJECT_CLASS (goa_daemon_parent_class)->finalize (object);
 }
@@ -164,13 +138,13 @@ create_monitor (const gchar *path, gboolean is_dir)
 static gboolean
 on_config_file_monitor_timeout (gpointer user_data)
 {
-  GoaDaemon *self = GOA_DAEMON (user_data);
+  GoaDaemon *daemon = GOA_DAEMON (user_data);
 
-  self->config_timeout_id = 0;
-  g_debug ("Reloading configuration files");
-  goa_daemon_reload_configuration (self);
+  daemon->config_timeout_id = 0;
+  g_info ("Reloading configuration files\n");
+  goa_daemon_reload_configuration (daemon);
 
-  return G_SOURCE_REMOVE;
+  return FALSE;
 }
 
 static void
@@ -180,52 +154,40 @@ on_file_monitor_changed (GFileMonitor      *monitor,
                          GFileMonitorEvent  event_type,
                          gpointer           user_data)
 {
-  GoaDaemon *self = GOA_DAEMON (user_data);
+  GoaDaemon *daemon = GOA_DAEMON (user_data);
 
-  if (self->config_timeout_id == 0)
+  if (daemon->config_timeout_id == 0)
     {
-      self->config_timeout_id = g_timeout_add (200, on_config_file_monitor_timeout, self);
+      daemon->config_timeout_id = g_timeout_add (200, on_config_file_monitor_timeout, daemon);
     }
 }
 
-static gboolean
-on_check_credentials_timeout (gpointer user_data)
-{
-  GoaDaemon *self = GOA_DAEMON (user_data);
-
-  self->credentials_timeout_id = 0;
-  g_debug ("Calling EnsureCredentials due to network changes");
-  goa_daemon_check_credentials (self);
-
-  return G_SOURCE_REMOVE;
-}
-
+#ifdef GOA_KERBEROS_ENABLED
 static void
-queue_check_credentials (GoaDaemon *self)
+activate_identity_service (GoaDaemon *daemon)
 {
-  if (self->credentials_timeout_id != 0)
+  GoaProvider *provider;
+
+  /* We activate the identity service implicitly by using the kerberos
+   * backend.  This way if the kerberos backend isn't enabled, we don't
+   * end up starting the identity service needlessly
+   */
+  provider = goa_provider_get_for_provider_type (GOA_KERBEROS_NAME);
+
+  if (provider != NULL)
     {
-      g_source_remove (self->credentials_timeout_id);
+      g_debug ("activated kerberos provider");
+      g_object_unref (provider);
     }
-
-  self->credentials_timeout_id = g_timeout_add_seconds (1, on_check_credentials_timeout, self);
 }
+#endif
 
 static void
-on_network_monitor_network_changed (GoaDaemon *self, gboolean available)
-{
-  queue_check_credentials (self);
-}
-
-static void
-goa_daemon_init (GoaDaemon *self)
+goa_daemon_init (GoaDaemon *daemon)
 {
   static volatile GQuark goa_error_domain = 0;
   GoaObjectSkeleton *object;
   gchar *path;
-#ifdef GOA_KERBEROS_ENABLED
-  GError *error = NULL;
-#endif
 
   /* this will force associating errors in the GOA_ERROR error domain
    * with org.freedesktop.Goa.Error.* errors via g_dbus_error_register_error_domain().
@@ -234,20 +196,20 @@ goa_daemon_init (GoaDaemon *self)
   goa_error_domain; /* shut up -Wunused-but-set-variable */
 
   /* TODO: maybe nicer to pass in a GDBusConnection* construct property */
-  self->connection = g_bus_get_sync (G_BUS_TYPE_SESSION, NULL, NULL);
+  daemon->connection = g_bus_get_sync (G_BUS_TYPE_SESSION, NULL, NULL);
 
   /* Create object manager */
-  self->object_manager = g_dbus_object_manager_server_new ("/org/gnome/OnlineAccounts");
+  daemon->object_manager = g_dbus_object_manager_server_new ("/org/gnome/OnlineAccounts");
 
   /* Create and export Manager */
-  self->manager = goa_manager_skeleton_new ();
-  g_signal_connect (self->manager,
+  daemon->manager = goa_manager_skeleton_new ();
+  g_signal_connect (daemon->manager,
                     "handle-add-account",
                     G_CALLBACK (on_manager_handle_add_account),
-                    self);
+                    daemon);
   object = goa_object_skeleton_new ("/org/gnome/OnlineAccounts/Manager");
-  goa_object_skeleton_set_manager (object, self->manager);
-  g_dbus_object_manager_server_export (self->object_manager, G_DBUS_OBJECT_SKELETON (object));
+  goa_object_skeleton_set_manager (object, daemon->manager);
+  g_dbus_object_manager_server_export (daemon->object_manager, G_DBUS_OBJECT_SKELETON (object));
   g_object_unref (object);
 
   /* create ~/.config/goa-1.0 directory */
@@ -260,37 +222,19 @@ goa_daemon_init (GoaDaemon *self)
 
   /* set up file monitoring */
   path = g_strdup_printf ("%s/goa-1.0/accounts.conf", g_get_user_config_dir ());
-  self->home_conf_file_monitor = create_monitor (path, FALSE);
-  if (self->home_conf_file_monitor != NULL)
-    g_signal_connect (self->home_conf_file_monitor, "changed", G_CALLBACK (on_file_monitor_changed), self);
+  daemon->home_conf_file_monitor = create_monitor (path, FALSE);
+  if (daemon->home_conf_file_monitor != NULL)
+    g_signal_connect (daemon->home_conf_file_monitor, "changed", G_CALLBACK (on_file_monitor_changed), daemon);
   g_free (path);
 
   /* prime the list of accounts */
-  goa_daemon_reload_configuration (self);
-
-  self->network_monitor = g_network_monitor_get_default ();
-  g_signal_connect_object (self->network_monitor,
-                           "network-changed",
-                           G_CALLBACK (on_network_monitor_network_changed),
-                           self,
-                           G_CONNECT_SWAPPED);
-
-  self->ensure_credentials_queue = g_queue_new ();
+  goa_daemon_reload_configuration (daemon);
 
   /* Export objects */
-  g_dbus_object_manager_server_set_connection (self->object_manager, self->connection);
-
-  queue_check_credentials (self);
+  g_dbus_object_manager_server_set_connection (daemon->object_manager, daemon->connection);
 
 #ifdef GOA_KERBEROS_ENABLED
-  self->identity_service = goa_identity_service_new ();
-  if (!goa_identity_service_activate (self->identity_service,
-                                      &error))
-    {
-      g_warning ("Error activating identity service: %s", error->message);
-      g_error_free (error);
-      g_clear_object (&self->identity_service);
-    }
+  activate_identity_service (daemon);
 #endif
 }
 
@@ -387,7 +331,7 @@ key_file_data_new (GKeyFile    *key_file,
 /* ---------------------------------------------------------------------------------------------------- */
 
 static void
-add_config_file (GoaDaemon     *self,
+add_config_file (GoaDaemon     *daemon,
                  const gchar   *path,
                  GHashTable    *group_name_to_key_file_data,
                  GList        **key_files_to_free)
@@ -419,7 +363,7 @@ add_config_file (GoaDaemon     *self,
       gsize num_groups;
       guint n;
 
-      guid = g_dbus_connection_get_guid (self->connection);
+      guid = g_dbus_connection_get_guid (daemon->connection);
       groups = g_key_file_get_groups (key_file, &num_groups);
       for (n = 0; n < num_groups; n++)
         {
@@ -477,7 +421,7 @@ add_config_file (GoaDaemon     *self,
 
 /* returns FALSE if object is not (or no longer) valid */
 static gboolean
-update_account_object (GoaDaemon           *self,
+update_account_object (GoaDaemon           *daemon,
                        GoaObjectSkeleton   *object,
                        const gchar         *path,
                        const gchar         *group,
@@ -496,14 +440,12 @@ update_account_object (GoaDaemon           *self,
   gchar *serialized_icon;
   GError *error;
 
-  g_return_val_if_fail (GOA_IS_DAEMON (self), FALSE);
+  g_return_val_if_fail (GOA_IS_DAEMON (daemon), FALSE);
   g_return_val_if_fail (G_IS_DBUS_OBJECT_SKELETON (object), FALSE);
   g_return_val_if_fail (group != NULL, FALSE);
   g_return_val_if_fail (key_file != NULL, FALSE);
 
   ret = FALSE;
-  account = NULL;
-  provider = NULL;
   identity = NULL;
   type = NULL;
   account = NULL;
@@ -541,7 +483,7 @@ update_account_object (GoaDaemon           *self,
   goa_account_set_is_locked (account, is_locked);
 
   error = NULL;
-  if (!goa_provider_build_object (provider, object, key_file, group, self->connection, just_added, &error))
+  if (!goa_provider_build_object (provider, object, key_file, group, daemon->connection, just_added, &error))
     {
       g_warning ("Error parsing account: %s (%s, %d)",
                  error->message, g_quark_to_string (error->domain), error->code);
@@ -560,10 +502,12 @@ update_account_object (GoaDaemon           *self,
 
  out:
   g_free (serialized_icon);
-  g_clear_object (&icon);
+  if (icon != NULL)
+    g_object_unref (icon);
   g_free (name);
-  g_clear_object (&provider);
-  g_clear_object (&account);
+  if (provider != NULL)
+    g_object_unref (provider);
+  g_object_unref (account);
   g_free (type);
   g_free (identity);
   g_free (presentation_identity);
@@ -578,7 +522,7 @@ object_path_to_group (const gchar *object_path)
 }
 
 static void
-process_config_entries (GoaDaemon  *self,
+process_config_entries (GoaDaemon  *daemon,
                         GHashTable *group_name_to_key_file_data)
 {
   GHashTableIter iter;
@@ -594,7 +538,7 @@ process_config_entries (GoaDaemon  *self,
   existing_object_paths = NULL;
   {
     GList *existing_objects;
-    existing_objects = g_dbus_object_manager_get_objects (G_DBUS_OBJECT_MANAGER (self->object_manager));
+    existing_objects = g_dbus_object_manager_get_objects (G_DBUS_OBJECT_MANAGER (daemon->object_manager));
     for (l = existing_objects; l != NULL; l = l->next)
       {
         GoaObject *object = GOA_OBJECT (l->data);
@@ -603,7 +547,8 @@ process_config_entries (GoaDaemon  *self,
         if (g_str_has_prefix (object_path, "/org/gnome/OnlineAccounts/Accounts/"))
           existing_object_paths = g_list_prepend (existing_object_paths, g_strdup (object_path));
       }
-    g_list_free_full (existing_objects, g_object_unref);
+    g_list_foreach (existing_objects, (GFunc) g_object_unref, NULL);
+    g_list_free (existing_objects);
   }
 
   config_object_paths = NULL;
@@ -637,14 +582,13 @@ process_config_entries (GoaDaemon  *self,
     {
       const gchar *object_path = l->data;
       GoaObject *object;
-      object = GOA_OBJECT (g_dbus_object_manager_get_object (G_DBUS_OBJECT_MANAGER (self->object_manager), object_path));
+      object = GOA_OBJECT (g_dbus_object_manager_get_object (G_DBUS_OBJECT_MANAGER (daemon->object_manager), object_path));
       g_warn_if_fail (object != NULL);
       g_signal_handlers_disconnect_by_func (goa_object_peek_account (object),
                                             G_CALLBACK (on_account_handle_remove),
-                                            self);
-      g_object_unref (object);
+                                            daemon);
       g_debug ("removing %s", object_path);
-      g_warn_if_fail (g_dbus_object_manager_server_unexport (self->object_manager, object_path));
+      g_warn_if_fail (g_dbus_object_manager_server_unexport (daemon->object_manager, object_path));
     }
   for (l = added; l != NULL; l = l->next)
     {
@@ -659,22 +603,22 @@ process_config_entries (GoaDaemon  *self,
       g_warn_if_fail (key_file_data != NULL);
 
       object = goa_object_skeleton_new (object_path);
-      if (update_account_object (self,
+      if (update_account_object (daemon,
                                  object,
                                  key_file_data->path,
                                  group,
                                  key_file_data->key_file,
                                  TRUE))
         {
-          g_dbus_object_manager_server_export (self->object_manager, G_DBUS_OBJECT_SKELETON (object));
+          g_dbus_object_manager_server_export (daemon->object_manager, G_DBUS_OBJECT_SKELETON (object));
           g_signal_connect (goa_object_peek_account (GOA_OBJECT (object)),
                             "handle-remove",
                             G_CALLBACK (on_account_handle_remove),
-                            self);
+                            daemon);
           g_signal_connect (goa_object_peek_account (GOA_OBJECT (object)),
                             "handle-ensure-credentials",
                             G_CALLBACK (on_account_handle_ensure_credentials),
-                            self);
+                            daemon);
         }
       g_object_unref (object);
       g_free (group);
@@ -691,9 +635,9 @@ process_config_entries (GoaDaemon  *self,
       key_file_data = g_hash_table_lookup (group_name_to_key_file_data, group);
       g_warn_if_fail (key_file_data != NULL);
 
-      object = GOA_OBJECT (g_dbus_object_manager_get_object (G_DBUS_OBJECT_MANAGER (self->object_manager), object_path));
+      object = GOA_OBJECT (g_dbus_object_manager_get_object (G_DBUS_OBJECT_MANAGER (daemon->object_manager), object_path));
       g_warn_if_fail (object != NULL);
-      if (!update_account_object (self,
+      if (!update_account_object (daemon,
                                   GOA_OBJECT_SKELETON (object),
                                   key_file_data->path,
                                   group,
@@ -702,11 +646,11 @@ process_config_entries (GoaDaemon  *self,
         {
           g_signal_handlers_disconnect_by_func (goa_object_peek_account (object),
                                                 G_CALLBACK (on_account_handle_remove),
-                                                self);
+                                                daemon);
           g_signal_handlers_disconnect_by_func (goa_object_peek_account (object),
                                                 G_CALLBACK (on_account_handle_ensure_credentials),
-                                                self);
-          g_warn_if_fail (g_dbus_object_manager_server_unexport (self->object_manager, object_path));
+                                                daemon);
+          g_warn_if_fail (g_dbus_object_manager_server_unexport (daemon->object_manager, object_path));
         }
       g_object_unref (object);
       g_free (group);
@@ -715,20 +659,22 @@ process_config_entries (GoaDaemon  *self,
   g_list_free (removed);
   g_list_free (added);
   g_list_free (unchanged);
-  g_list_free_full (existing_object_paths, g_free);
-  g_list_free_full (config_object_paths, g_free);
+  g_list_foreach (existing_object_paths, (GFunc) g_free, NULL);
+  g_list_free (existing_object_paths);
+  g_list_foreach (config_object_paths, (GFunc) g_free, NULL);
+  g_list_free (config_object_paths);
 }
 
 /* <internal>
  * goa_daemon_reload_configuration:
- * @self: A #GoaDaemon
+ * @daemon: A #GoaDaemon
  *
  * Updates the accounts_objects member from stored configuration -
  * typically called at startup or when a change on the configuration
  * files has been detected.
  */
 static void
-goa_daemon_reload_configuration (GoaDaemon *self)
+goa_daemon_reload_configuration (GoaDaemon *daemon)
 {
   GList *key_files_to_free;
   GHashTable *group_name_to_key_file_data;
@@ -742,18 +688,19 @@ goa_daemon_reload_configuration (GoaDaemon *self)
 
   /* Read the main user config file at $HOME/.config/goa-1.0/accounts.conf */
   path = g_strdup_printf ("%s/goa-1.0/accounts.conf", g_get_user_config_dir ());
-  add_config_file (self, path, group_name_to_key_file_data, &key_files_to_free);
+  add_config_file (daemon, path, group_name_to_key_file_data, &key_files_to_free);
   g_free (path);
 
   /* now process the group_name_to_key_file_data hash table */
-  process_config_entries (self, group_name_to_key_file_data);
+  process_config_entries (daemon, group_name_to_key_file_data);
 
   g_hash_table_unref (group_name_to_key_file_data);
-  g_list_free_full (key_files_to_free, (GDestroyNotify) g_key_file_free);
+  g_list_foreach (key_files_to_free, (GFunc) g_key_file_free, NULL);
+  g_list_free (key_files_to_free);
 }
 
 static gchar *
-generate_new_id (GoaDaemon *self)
+generate_new_id (GoaDaemon *daemon)
 {
   static guint counter = 0;
   GDateTime *dt;
@@ -947,7 +894,8 @@ get_all_providers_cb (GObject      *source,
 
  out:
   g_free (object_path);
-  g_list_free_full (providers, g_object_unref);
+  if (providers != NULL)
+    g_list_free_full (providers, g_object_unref);
   g_free (key_file_data);
   g_free (group);
   g_free (id);
@@ -976,11 +924,11 @@ on_manager_handle_add_account (GoaManager             *manager,
                                GVariant               *details,
                                gpointer                user_data)
 {
-  GoaDaemon *self = GOA_DAEMON (user_data);
+  GoaDaemon *daemon = GOA_DAEMON (user_data);
   AddAccountData *data;
 
   data = g_slice_new0 (AddAccountData);
-  data->daemon = g_object_ref (self);
+  data->daemon = g_object_ref (daemon);
   data->manager = g_object_ref (manager);
   data->invocation = g_object_ref (invocation);
   data->provider_type = g_strdup (provider_type);
@@ -1001,7 +949,7 @@ on_account_handle_remove (GoaAccount            *account,
                           GDBusMethodInvocation *invocation,
                           gpointer               user_data)
 {
-  GoaDaemon *self = GOA_DAEMON (user_data);
+  GoaDaemon *daemon = GOA_DAEMON (user_data);
   GoaProvider *provider;
   GKeyFile *key_file;
   const gchar *provider_type;
@@ -1109,12 +1057,13 @@ on_account_handle_remove (GoaAccount            *account,
       goto out;
     }
 
-  goa_daemon_reload_configuration (self);
+  goa_daemon_reload_configuration (daemon);
 
   goa_account_complete_remove (account, invocation);
 
  out:
-  g_clear_object (&provider);
+  if (provider != NULL)
+    g_object_unref (provider);
   g_free (data);
   if (key_file != NULL)
     g_key_file_free (key_file);
@@ -1127,25 +1076,28 @@ on_account_handle_remove (GoaAccount            *account,
 
 typedef struct
 {
+  GoaDaemon *daemon;
   GoaObject *object;
-  GList *invocations;
+  GDBusMethodInvocation *invocation;
 } EnsureData;
 
 static EnsureData *
-ensure_data_new (GoaObject             *object,
-                 GDBusMethodInvocation *invocation)
+ensure_data_new (GoaDaemon             *daemon,
+                             GoaObject             *object,
+                             GDBusMethodInvocation *invocation)
 {
   EnsureData *data;
   data = g_slice_new0 (EnsureData);
+  data->daemon = g_object_ref (daemon);
   data->object = g_object_ref (object);
-  data->invocations = g_list_prepend (data->invocations, invocation);
+  data->invocation = invocation;
   return data;
 }
 
 static void
 ensure_data_unref (EnsureData *data)
 {
-  g_list_free (data->invocations);
+  g_object_unref (data->daemon);
   g_object_unref (data->object);
   g_slice_free (EnsureData, data);
 }
@@ -1172,48 +1124,13 @@ is_authorization_error (GError *error)
 }
 
 static void
-ensure_credentials_queue_complete (GList *invocations, GoaAccount *account, gint expires_in, GError *error)
+ensure_credentials_cb (GoaProvider   *provider,
+                       GAsyncResult  *res,
+                       gpointer       user_data)
 {
-  GList *l;
-  const gchar *id;
-  const gchar *provider_type;
-  gint64 timestamp;
-
-  for (l = invocations; l != NULL; l = l->next)
-    {
-      GDBusMethodInvocation *invocation = G_DBUS_METHOD_INVOCATION (l->data);
-
-      if (invocation == NULL)
-        continue;
-
-      if (error == NULL)
-        goa_account_complete_ensure_credentials (account, invocation, expires_in);
-      else
-        g_dbus_method_invocation_return_gerror (invocation, error);
-    }
-
-  id = goa_account_get_id (account);
-  provider_type = goa_account_get_provider_type (account);
-  timestamp = g_get_monotonic_time ();
-  g_debug ("%" G_GINT64_FORMAT ": Handled EnsureCredentials (%s, %s)", timestamp, provider_type, id);
-}
-
-static void
-ensure_credentials_queue_collector (GObject *source_object, GAsyncResult *res, gpointer user_data)
-{
-  GTask *task = G_TASK (user_data);
-  GoaDaemon *self;
-  EnsureData *data;
-  GoaAccount *account;
-  GoaProvider *provider = GOA_PROVIDER (source_object);
-  GError *error;
+  EnsureData *data = user_data;
   gint expires_in;
-
-  self = GOA_DAEMON (g_task_get_source_object (task));
-  g_assert (task == G_TASK (g_queue_pop_head (self->ensure_credentials_queue)));
-
-  data = g_task_get_task_data (task);
-  account = goa_object_peek_account (data->object);
+  GError *error;
 
   error= NULL;
   if (!goa_provider_ensure_credentials_finish (provider, &expires_in, res, &error))
@@ -1221,6 +1138,8 @@ ensure_credentials_queue_collector (GObject *source_object, GAsyncResult *res, g
       /* Set AttentionNeeded only if the error is an authorization error */
       if (is_authorization_error (error))
         {
+          GoaAccount *account;
+          account = goa_object_peek_account (data->object);
           if (!goa_account_get_attention_needed (account))
             {
               goa_account_set_attention_needed (account, TRUE);
@@ -1230,12 +1149,13 @@ ensure_credentials_queue_collector (GObject *source_object, GAsyncResult *res, g
                          error->message, g_quark_to_string (error->domain), error->code);
             }
         }
-
-      ensure_credentials_queue_complete (data->invocations, account, 0, error);
-      g_error_free (error);
+      g_dbus_method_invocation_take_error (data->invocation, error);
     }
   else
     {
+      GoaAccount *account;
+      account = goa_object_peek_account (data->object);
+
       /* Clear AttentionNeeded flag if set */
       if (goa_account_get_attention_needed (account))
         {
@@ -1244,112 +1164,11 @@ ensure_credentials_queue_collector (GObject *source_object, GAsyncResult *res, g
           g_message ("%s: Setting AttentionNeeded to FALSE because EnsureCredentials() succeded\n",
                      g_dbus_object_get_object_path (G_DBUS_OBJECT (data->object)));
         }
-
-      ensure_credentials_queue_complete (data->invocations, account, expires_in, NULL);
+      goa_account_complete_ensure_credentials (goa_object_peek_account (data->object),
+                                               data->invocation,
+                                               expires_in);
     }
-
-  self->ensure_credentials_running = FALSE;
-  ensure_credentials_queue_check (self);
-  g_object_unref (task);
-}
-
-static gint
-ensure_credentials_queue_sort (gconstpointer a, gconstpointer b, gpointer user_data)
-{
-  GTask *task_a = G_TASK (a);
-  GTask *task_b = G_TASK (b);
-  gint priority_a;
-  gint priority_b;
-
-  priority_a = g_task_get_priority (task_a);
-  priority_b = g_task_get_priority (task_b);
-
-  return priority_a - priority_b;
-}
-
-static void
-ensure_credentials_queue_check (GoaDaemon *self)
-{
-  EnsureData *data;
-  GoaAccount *account;
-  GoaProvider *provider = NULL;
-  GTask *task;
-  const gchar *id;
-  const gchar *provider_type;
-  gint64 timestamp;
-
-  if (self->ensure_credentials_running)
-    goto out;
-
-  if (self->ensure_credentials_queue->length == 0)
-    goto out;
-
-  g_queue_sort (self->ensure_credentials_queue, ensure_credentials_queue_sort, NULL);
-
-  task = G_TASK (g_queue_peek_head (self->ensure_credentials_queue));
-  self->ensure_credentials_running = TRUE;
-
-  data = (EnsureData *) g_task_get_task_data (task);
-  account = goa_object_peek_account (data->object);
-
-  id = goa_account_get_id (account);
-  provider_type = goa_account_get_provider_type (account);
-  timestamp = g_get_monotonic_time ();
-  g_debug ("%" G_GINT64_FORMAT ": Handling EnsureCredentials (%s, %s)", timestamp, provider_type, id);
-
-  provider = goa_provider_get_for_provider_type (provider_type);
-  g_assert_nonnull (provider);
-
-  goa_provider_ensure_credentials (provider,
-                                   data->object,
-                                   NULL, /* GCancellable */
-                                   ensure_credentials_queue_collector,
-                                   task);
-
- out:
-  g_clear_object (&provider);
-}
-
-static gboolean
-ensure_credentials_queue_coalesce (GoaDaemon *self, GoaObject *object, GDBusMethodInvocation *invocation)
-{
-  GList *l;
-  GoaAccount *account;
-  const gchar *id;
-  gboolean ret = FALSE;
-  gint priority;
-
-  account = goa_object_peek_account (object);
-  id = goa_account_get_id (account);
-
-  priority = (invocation == NULL) ? G_PRIORITY_LOW : G_PRIORITY_HIGH;
-
-  for (l = self->ensure_credentials_queue->head; l != NULL; l = l->next)
-    {
-      GoaAccount *account_queued;
-      GTask *task = G_TASK (l->data);
-      EnsureData *data;
-      const gchar *id_queued;
-
-      data = g_task_get_task_data (task);
-      account_queued = goa_object_peek_account (data->object);
-      id_queued = goa_account_get_id (account_queued);
-      if (g_strcmp0 (id, id_queued) == 0)
-        {
-          gint priority_queued;
-
-          priority_queued = g_task_get_priority (task);
-          if (priority < priority_queued)
-            g_task_set_priority (task, priority);
-
-          data->invocations = g_list_prepend (data->invocations, invocation);
-
-          ret = TRUE;
-          break;
-        }
-    }
-
-  return ret;
+  ensure_data_unref (data);
 }
 
 static gboolean
@@ -1357,125 +1176,29 @@ on_account_handle_ensure_credentials (GoaAccount            *account,
                                       GDBusMethodInvocation *invocation,
                                       gpointer               user_data)
 {
-  GoaDaemon *self = GOA_DAEMON (user_data);
-  EnsureData *data;
+  GoaDaemon *daemon = GOA_DAEMON (user_data);
+  GoaProvider *provider;
   GoaObject *object;
-  GoaProvider *provider = NULL;
-  GTask *task = NULL;
-  const gchar *id;
-  const gchar *method_name;
-  const gchar *provider_type;
-  gint64 timestamp;
 
-  id = goa_account_get_id (account);
-  provider_type = goa_account_get_provider_type (account);
-  method_name = g_dbus_method_invocation_get_method_name (invocation);
-  timestamp = g_get_monotonic_time ();
-  g_debug ("%" G_GINT64_FORMAT ": Received %s (%s, %s)", timestamp, method_name, provider_type, id);
-
-  provider = goa_provider_get_for_provider_type (provider_type);
+  object = GOA_OBJECT (g_dbus_interface_get_object (G_DBUS_INTERFACE (account)));
+  provider = goa_provider_get_for_provider_type (goa_account_get_provider_type (account));
   if (provider == NULL)
     {
       g_dbus_method_invocation_return_error (invocation,
                                              GOA_ERROR,
                                              GOA_ERROR_FAILED,
                                              "Unsupported account type %s for id %s (no provider)",
-                                             provider_type,
-                                             id);
+                                             goa_account_get_provider_type (account),
+                                             goa_account_get_id (account));
       goto out;
     }
 
-  object = GOA_OBJECT (g_dbus_interface_get_object (G_DBUS_INTERFACE (account)));
-  if (ensure_credentials_queue_coalesce (self, object, invocation))
-    {
-      timestamp = g_get_monotonic_time ();
-      g_debug ("%" G_GINT64_FORMAT ": Coalesced %s (%s, %s)",
-               timestamp,
-               method_name,
-               provider_type,
-               id);
-      goto out;
-    }
-
-  data = ensure_data_new (object, invocation);
-
-  task = g_task_new (self, NULL, NULL, NULL);
-  g_task_set_priority (task, G_PRIORITY_HIGH);
-  g_task_set_task_data (task, data, (GDestroyNotify) ensure_data_unref);
-  g_queue_push_tail (self->ensure_credentials_queue, g_object_ref (task));
-
-  ensure_credentials_queue_check (self);
+  goa_provider_ensure_credentials (provider,
+                                   object,
+                                   NULL, /* GCancellable */
+                                   (GAsyncReadyCallback) ensure_credentials_cb,
+                                   ensure_data_new (daemon, object, invocation));
 
  out:
-  g_clear_object (&provider);
-  g_clear_object (&task);
   return TRUE; /* invocation was handled */
 }
-
-/* <internal>
- * goa_daemon_check_credentials:
- * @self: A #GoaDaemon
- *
- * Checks whether credentials are valid and tries to refresh them if
- * not. It also reports whether accounts are usable with the current
- * network.
- */
-static void
-goa_daemon_check_credentials (GoaDaemon *self)
-{
-  GList *l;
-  GList *objects;
-
-  objects = g_dbus_object_manager_get_objects (G_DBUS_OBJECT_MANAGER (self->object_manager));
-  for (l = objects; l != NULL; l = l->next)
-    {
-      EnsureData *data;
-      GoaAccount *account;
-      GoaObject *object = GOA_OBJECT (l->data);
-      GoaProvider *provider = NULL;
-      GTask *task = NULL;
-      const gchar *id;
-      const gchar *provider_type;
-      gint64 timestamp;
-
-      account = goa_object_peek_account (object);
-      if (account == NULL)
-        continue;
-
-      provider_type = goa_account_get_provider_type (account);
-      provider = goa_provider_get_for_provider_type (provider_type);
-      if (provider == NULL)
-        continue;
-
-      id = goa_account_get_id (account);
-      provider_type = goa_account_get_provider_type (account);
-      timestamp = g_get_monotonic_time ();
-      g_debug ("%" G_GINT64_FORMAT ": Calling EnsureCredentials (%s, %s)",
-               timestamp,
-               provider_type,
-               id);
-
-      if (ensure_credentials_queue_coalesce (self, object, NULL))
-        {
-          timestamp = g_get_monotonic_time ();
-          g_debug ("%" G_GINT64_FORMAT ": Coalesced EnsureCredentials (%s, %s)",
-                   timestamp,
-                   provider_type,
-                   id);
-          continue;
-        }
-
-      data = ensure_data_new (object, NULL);
-
-      task = g_task_new (self, NULL, NULL, NULL);
-      g_task_set_priority (task, G_PRIORITY_LOW);
-      g_task_set_task_data (task, data, (GDestroyNotify) ensure_data_unref);
-      g_queue_push_tail (self->ensure_credentials_queue, g_object_ref (task));
-
-      g_clear_object (&provider);
-      g_clear_object (&task);
-    }
-
-  ensure_credentials_queue_check (self);
-  g_list_free_full (objects, g_object_unref);
-}
