@@ -221,14 +221,7 @@ ews_client_autodiscover_response_cb (SoupSession *session, SoupMessage *msg, gpo
    * successful.
    */
   if (status == SOUP_STATUS_CANCELLED)
-    {
-      /* If a previous autodiscover attempt for the same GAsyncResult
-       * was successful then no additional attempts are required and
-       * we should use the result from the earlier attempt.
-       */
-      op_res = g_simple_async_result_get_op_res_gboolean (data->res);
-      goto out;
-    }
+    goto out;
   else if (status != SOUP_STATUS_OK)
     {
       g_set_error (&error,
@@ -316,12 +309,6 @@ ews_client_autodiscover_response_cb (SoupSession *session, SoupMessage *msg, gpo
       goto out;
     }
 
-  /* This autodiscover attempt was successful. Save the result now so
-   * that it won't get lost when we hear from another autodiscover
-   * attempt for the same GAsyncResult.
-   */
-  g_simple_async_result_set_op_res_gboolean (data->res, op_res);
-
   for (idx = 0; idx < size; idx++)
     {
       if (data->msgs[idx] != NULL)
@@ -355,12 +342,7 @@ ews_client_autodiscover_response_cb (SoupSession *session, SoupMessage *msg, gpo
       GMainContext *context;
       GSource *source;
 
-      /* The result of the GAsyncResult should already be set when we
-       * get here. If it wasn't explicitly set to TRUE then
-       * autodiscovery has failed and the default value of the
-       * GAsyncResult (which is FALSE) should be returned to the
-       * original caller.
-       */
+      g_simple_async_result_set_op_res_gboolean (data->res, op_res);
 
       source = g_idle_source_new ();
       g_source_set_priority (source, G_PRIORITY_DEFAULT_IDLE);
