@@ -1,6 +1,6 @@
 /* -*- mode: C; c-file-style: "gnu"; indent-tabs-mode: nil; -*- */
 /*
- * Copyright (C) 2011, 2012, 2013, 2014 Red Hat, Inc.
+ * Copyright (C) 2011, 2012, 2013, 2014, 2015 Red Hat, Inc.
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -92,6 +92,7 @@ get_provider_features (GoaProvider *provider)
          GOA_PROVIDER_FEATURE_CHAT |
          GOA_PROVIDER_FEATURE_DOCUMENTS |
          GOA_PROVIDER_FEATURE_PHOTOS |
+         GOA_PROVIDER_FEATURE_FILES |
          GOA_PROVIDER_FEATURE_PRINTERS;
 }
 
@@ -131,8 +132,10 @@ get_scope (GoaOAuth2Provider *oauth2_provider)
          /* Google Contacts API (CardDAV) - undocumented */
          "https://www.googleapis.com/auth/carddav "
 
+         /* Google Drive API */
+         "https://www.googleapis.com/auth/drive "
+
          /* Google Documents List Data API */
-         "https://docs.google.com/feeds/ "
          "https://docs.googleusercontent.com/ "
          "https://spreadsheets.google.com/feeds/ "
 
@@ -155,7 +158,7 @@ get_scope (GoaOAuth2Provider *oauth2_provider)
 static guint
 get_credentials_generation (GoaProvider *provider)
 {
-  return 9;
+  return 10;
 }
 
 static const gchar *
@@ -257,7 +260,6 @@ get_identity_sync (GoaOAuth2Provider  *oauth2_provider,
     *out_presentation_identity = g_strdup (ret); /* for now: use email as presentation identity */
 
  out:
-  g_clear_object (&parser);
   g_clear_error (&identity_error);
   g_clear_object (&call);
   g_clear_object (&proxy);
@@ -319,6 +321,7 @@ build_object (GoaProvider         *provider,
   GoaContacts *contacts;
   GoaChat *chat;
   GoaDocuments *documents;
+  GoaFiles *files;
   GoaPhotos *photos;
   GoaPrinters *printers;
   gboolean ret;
@@ -327,6 +330,7 @@ build_object (GoaProvider         *provider,
   gboolean contacts_enabled;
   gboolean chat_enabled;
   gboolean documents_enabled;
+  gboolean files_enabled;
   gboolean photos_enabled;
   gboolean printers_enabled;
   const gchar *email_address;
@@ -337,6 +341,7 @@ build_object (GoaProvider         *provider,
   contacts = NULL;
   chat = NULL;
   documents = NULL;
+  files = NULL;
   photos = NULL;
   printers = NULL;
   ret = FALSE;
@@ -485,6 +490,30 @@ build_object (GoaProvider         *provider,
         goa_object_skeleton_set_photos (object, NULL);
     }
 
+  /* Files */
+  files = goa_object_get_files (GOA_OBJECT (object));
+  files_enabled = g_key_file_get_boolean (key_file, group, "FilesEnabled", NULL);
+  if (files_enabled)
+    {
+      if (files == NULL)
+        {
+          gchar *uri_drive;
+
+          uri_drive = g_strconcat ("google-drive://", email_address, "/", NULL);
+          files = goa_files_skeleton_new ();
+          g_object_set (G_OBJECT (files),
+                        "uri", uri_drive,
+                        NULL);
+          goa_object_skeleton_set_files (object, files);
+          g_free (uri_drive);
+        }
+    }
+  else
+    {
+      if (files != NULL)
+        goa_object_skeleton_set_files (object, NULL);
+    }
+
   /* Printers */
   printers = goa_object_get_printers (GOA_OBJECT (object));
   printers_enabled = g_key_file_get_boolean (key_file, group, "PrintersEnabled", NULL);
@@ -511,6 +540,7 @@ build_object (GoaProvider         *provider,
       goa_account_set_chat_disabled (account, !chat_enabled);
       goa_account_set_documents_disabled (account, !documents_enabled);
       goa_account_set_photos_disabled (account, !photos_enabled);
+      goa_account_set_files_disabled (account, !files_enabled);
       goa_account_set_printers_disabled (account, !printers_enabled);
 
       g_signal_connect (account,
@@ -537,6 +567,10 @@ build_object (GoaProvider         *provider,
                         "notify::photos-disabled",
                         G_CALLBACK (goa_util_account_notify_property_cb),
                         "PhotosEnabled");
+      g_signal_connect (account,
+                        "notify::files-disabled",
+                        G_CALLBACK (goa_util_account_notify_property_cb),
+                        "FilesEnabled");
       g_signal_connect (account,
                         "notify::printers-disabled",
                         G_CALLBACK (goa_util_account_notify_property_cb),
@@ -547,6 +581,7 @@ build_object (GoaProvider         *provider,
 
  out:
   g_clear_object (&printers);
+  g_clear_object (&files);
   g_clear_object (&photos);
   g_clear_object (&documents);
   g_clear_object (&chat);
@@ -613,6 +648,11 @@ show_account (GoaProvider         *provider,
                                                    "photos-disabled",
                                                    _("_Photos"));
 
+  goa_util_add_row_switch_from_keyfile_with_blurb (grid, row++, object,
+                                                   NULL,
+                                                   "files-disabled",
+                                                   _("_Files"));
+
   goa_util_add_row_switch_from_keyfile_with_blurb (grid, row++, object,
                                                    NULL,
                                                    "printers-disabled",
@@ -631,6 +671,7 @@ add_account_key_values (GoaOAuth2Provider  *oauth2_provider,
   g_variant_builder_add (builder, "{ss}", "ChatEnabled", "true");
   g_variant_builder_add (builder, "{ss}", "DocumentsEnabled", "true");
   g_variant_builder_add (builder, "{ss}", "PhotosEnabled", "true");
+  g_variant_builder_add (builder, "{ss}", "FilesEnabled", "true");
   g_variant_builder_add (builder, "{ss}", "PrintersEnabled", "true");
 }
 
