@@ -1,6 +1,6 @@
 /* -*- mode: C; c-file-style: "gnu"; indent-tabs-mode: nil; -*- */
 /*
- * Copyright (C) 2011, 2012, 2014 Red Hat, Inc.
+ * Copyright (C) 2011, 2012, 2014, 2015 Red Hat, Inc.
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -26,7 +26,7 @@
 #include <goabackend/goaprovider.h>
 #include <goabackend/goaprovider-priv.h>
 #include <rest/rest-proxy-call.h>
-#include <webkit/webkit.h>
+#include <webkitdom/webkitdom.h>
 
 G_BEGIN_DECLS
 
@@ -110,18 +110,20 @@ struct _GoaOAuthProviderClass
                                                 GVariantBuilder              *builder);
 
   /* pure virtual */
-  gboolean     (*is_deny_node)                 (GoaOAuthProvider             *provider,
-                                                WebKitDOMNode                *node);
   gboolean     (*is_identity_node)             (GoaOAuthProvider             *provider,
                                                 WebKitDOMHTMLInputElement    *element);
 
   /* virtual but with default implementation */
+  gboolean     (*is_deny_node)                 (GoaOAuthProvider             *provider,
+                                                WebKitDOMNode                *node);
   gboolean     (*is_password_node)             (GoaOAuthProvider             *provider,
                                                 WebKitDOMHTMLInputElement    *element);
 
   /*< private >*/
+  GoaOAuthProviderPrivate *priv;
+
   /* Padding for future expansion */
-  gpointer goa_reserved[29];
+  gpointer goa_reserved[28];
 };
 
 GType        goa_oauth_provider_get_type                     (void) G_GNUC_CONST;
