@@ -1070,11 +1070,8 @@ goa_provider_get_all (GAsyncReadyCallback callback,
   for (l = extensions, i = 0; l != NULL; l = l->next, i++)
     {
       GIOExtension *extension = l->data;
-      GoaProviderFactory *factory;
-
-      factory = GOA_PROVIDER_FACTORY (g_object_new (g_io_extension_get_type (extension), NULL));
-      goa_provider_factory_get_providers (factory, get_providers_cb, data);
-      g_object_unref (factory);
+      goa_provider_factory_get_providers (g_object_new (g_io_extension_get_type (extension), NULL),
+          get_providers_cb, data);
       data->pending_calls++;
     }
 
